import sys
import gi
gi.require_version('Notify', '0.7')  # Version festlegen
from gi.repository import Notify

def notify(app_name, title, message):
    Notify.init(app_name)
    notification = Notify.Notification.new(title, message)
    notification.show()

if __name__ == "__main__":
    if len(sys.argv) != 4:  # sys.argv[0] (Skriptname) + 3 Argumente
        print("Usage: python3 PyNotifier.py <app_name> <title> <message>")
    else:
        app_name = sys.argv[1]
        title = sys.argv[2]
        message = sys.argv[3]
        notify(app_name, title, message)



from setuptools import setup, find_packages

setup(
    name="NotipyDesktop",  # Der Name des Pakets
    version="2.0.0",  # Versionsnummer
    description="A simple Python notification library using libnotify.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    author="Michael Christian Dörflinger",
    author_email="michaeldoerflinger93@gmail.com",
    url="https://github.com/Michdo93/NotipyDesktop",
    packages=find_packages(),
    install_requires=[
        "PyGObject",  # Abhängigkeiten
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",
)
